MinMaxHeuristic
MinMaxHeuristic(edge='max', measure='frequency', number=1, boundary=1200)
A heuristic class for min/max frequencies and bandwidths
Examples
To define an F1 maximum:
F1_Max = MinMaxHeuristic(
edge="max",
measure="frequency",
number=1,
boundary=1200
)
Parameters
| edge |
Literal['min', 'max'] |
Whether this heuristic defines a min or a max |
'max' |
| measure |
Literal['frequency', 'bandwidth'] |
(Literal[“frequency”, “bandwidth”]): Whether this heuristic is defined over frequencies or bandwidths |
'frequency' |
| number |
int |
The formant number |
1 |
| boundary |
float | int | np.floating |
The min or max value. |
1200 |
Methods
| eval |
Evaluate whether or not the track passes the |
eval
MinMaxHeuristic.eval(track)
Evaluate whether or not the track passes the heuristic
Parameters
| track |
OneTrack |
The track to evaluate |
required |
Returns
|
Literal[0 | np.inf] |
If it passes the heuristic, 0. If it doesn’t, np.inf |