Smoother

Smoother(method='dct_smooth_regression', **kwargs)

A smoother function factory

Parameters

Name Type Description Default
method Union[str, Callable] The smoothing method to use. Defaults to “dct_smooth”. Can be a custom smoother such that it takes a 1D array as input and returns a Smoothed class. 'dct_smooth_regression'
kwargs Any additional arguments or parameters for the method. required

Methods

Name Description
smooth Apply the smoother function to the data

smooth

Smoother.smooth(x)

Apply the smoother function to the data

Parameters

Name Type Description Default
x np.array a 1D numpy array required

Returns

Name Type Description
Smoothed A Smoothed object